/* -- $Id: MHTConverter.java,v 1.2 2003/09/24 14:39:16 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.core;

import java.io.*;

import com.aurigalogic.aurigadoc.util.MHTCompiler;

/**
 * This class is used for converting AurigaDoc document to mht.
 * 
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.2 $ $Date: 2003/09/24 14:39:16 $
 */

public class MHTConverter extends BaseConverter {

	/** Identifier for setting the mail option */
	public static final String SEND_MAIL = "send_mail";

	/** Identifier for setting the subject field */
	public static final String SUBJECT = "subject";

	/** Identifier for setting the to field */
	public static final String TO = "to";

	/** Identifier for setting the from field */
	public static final String FROM = "from";

	/** Identifier for setting the cc field */
	public static final String CC = "cc";

	/** Identifier for setting the bcc field */
	public static final String BCC = "bcc";

	/**
	 * Main method which does the conversion.
	 * @throws Exception in case of an error
	 */
	public void convert() throws Exception {
		logInfo("Converting to HTML..");
		FileOutputStream fos = new FileOutputStream(outputFile + ".html");
		doTransform(new FileInputStream(inputFile), 
			fos, getXSLForKey(XSL, XML2HTML), OUTPUT_HTML);
		fos.close();
		
		// now create the archive
		logInfo("Compiling MHT..");
		MHTCompiler compiler = new MHTCompiler(outputFile + ".html", outputFile);
		compiler.setSmtp(getProperty("smtp"));
		setCompilerOptions(compiler);
		compiler.compile();

		File temp = new File(outputFile + ".html");
		temp.delete();
	}

	private void setCompilerOptions(MHTCompiler compiler) {
		String param = null;
		// send mail
		param = getParameter(SEND_MAIL);
		if (param != null && param.equals("y")) {
			compiler.setSendMail(true);
		}

		// subject
		param = getParameter(SUBJECT);
		if (param != null) {
			compiler.setSubject(param);
		}

		// from 
		param = getParameter(FROM);
		if (param != null) {
			compiler.setFrom(param);
		}

		// to 
		param = getParameter(TO);
		if (param != null) {
			compiler.setTo(param);
		}

		// cc 
		param = getParameter(CC);
		if (param != null) {
			compiler.setCc(param);
		}

		// bcc 
		param = getParameter(BCC);
		if (param != null) {
			compiler.setBcc(param);
		}
	}

}
