/* -- $Id: JHelpViewer.java,v 1.4 2003/11/06 07:04:23 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.util;

import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import javax.help.*;
import java.net.*;

/**
 * This class is the used for rendering the converted html docs in java help 
 * viewer.
 *
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.4 $ $Date: 2003/11/06 07:04:23 $
 */

public class JHelpViewer extends JFrame {

	/**
	 * Prints the usage info and exits.
	 */
	private static void printUsage() {
		System.out.println("\nUsage: "
			+ "java com.aurigalogic.aurigadoc.JHelpViewer "
			+ "resourcepath helpsetname");
	}

	/**
	 * Default constructor to create a Java helpset Viewer with 
	 * the given helpset name in the given resource path.
	 *
	 * @param reourcePath - the path of the dir or the jar file where the
	 * java help system files are located.
	 * @param helpsetName - the helpset name without prefix. 
	 * Prefix is assumed to be .hs
	 */
	public JHelpViewer(String reourcePath, String helpsetName) {
		super("AurigaDoc: Java Help Viewer");
		Container contentPane = getContentPane();
		URL hsURL;
		HelpSet hs;
		try {
			String urlString = "file:" + reourcePath;
			if (reourcePath.endsWith(".jar")) {
				urlString = "jar:file:" + reourcePath + "!";
			}
			urlString += "/" + helpsetName + ".hs";

			// get the system class loader
			ClassLoader cl = ClassLoader.getSystemClassLoader();

			// get the helpset url
			hsURL = new URL(urlString);

			// create helpset
			hs = new HelpSet(cl, hsURL);
			JHelp jhelp = new JHelp(hs);
			contentPane.setLayout(new BorderLayout());
			contentPane.add(jhelp);

			addWindowListener( new WindowAdapter() {
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});  
		} catch (Exception ee) {
			System.out.println("HelpSet " + helpsetName + " not found");
			ee.printStackTrace();
			return;
		}
		setIcon();
		pack();
		setVisible(true); 
	}

	private void setIcon() {
		try {
			URL url = getClass().getResource("/favicon.gif");
			ImageIcon icon = new ImageIcon(url);
			setIconImage(icon.getImage());
		} catch (Exception e) {
			// do n othing
		}
	}

	/**
	 * Command line entry.
	 * @param args the command line arguments.
	 */
	public static void main(String[] args) {
        try {
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
        } catch (Exception e) {
			// do nothing
		}    
		
        try {
			JHelpViewer viewer = new JHelpViewer(args[0], args[1]);
		} catch (ArrayIndexOutOfBoundsException aiobe) {
			printUsage();
		}
	}

}
